==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/mad/translations/mad_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru">
<defaultcodec></defaultcodec>
<context>
    <name>DecoderMADFactory</name>
    <message>
        <location filename="../decodermadfactory.cpp" line="67"/>
        <source>MPEG Plugin</source>
        <translation>Модуль MPEG</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="69"/>
        <source>MPEG Files</source>
        <translation>Файлы MPEG</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="183"/>
        <source>About MPEG Audio Plugin</source>
        <translation>Об аудио-модуле MPEG</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="184"/>
        <source>Qmmp MPEG Audio Plugin</source>
        <translation>Аудио-модуль MPEG для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="185"/>
        <source>Compiled against libmad version:</source>
        <translation>Собрано с версией libmad:</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="189"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="191"/>
        <source>Source code based on mq3 progect</source>
        <translation>Исходный код основан на проекте mq3</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="103"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="130"/>
        <source>Yes</source>
        <translation>Есть</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="132"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="223"/>
        <source>ID3v1 Tag</source>
        <translation>ID3v1-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="461"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="377"/>
        <source>Track number:</source>
        <translation>Номер трека:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="351"/>
        <source>Year:</source>
        <translation>Год:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="403"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="325"/>
        <source>Comment:</source>
        <translation>Комментарий:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="299"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="273"/>
        <source>Artist:</source>
        <translation>Исполнитель:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="247"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="484"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="151"/>
        <source>ID3v2 Tag</source>
        <translation>ID3v2-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="90"/>
        <source>MPEG Info</source>
        <translation>Информация MPEG</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="211"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="201"/>
        <source>Original:</source>
        <translation>Оригинальный:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="184"/>
        <source>Copyright:</source>
        <translation>Авторские права:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="167"/>
        <source>Mode:</source>
        <translation>Режим:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="150"/>
        <source>File size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="133"/>
        <source>Sample rate:</source>
        <translation>Дискретизация:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="116"/>
        <source>Bit rate:</source>
        <translation>Битовая частота:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="96"/>
        <source>MPEG level:</source>
        <translation>Уровень MPEG:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="27"/>
        <source>File path:</source>
        <translation>Путь к файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="119"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>Details</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="101"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="155"/>
        <source>APE Tag</source>
        <translation>APE-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="54"/>
        <source>Tag Choice</source>
        <translation>Выбор тегов</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="60"/>
        <source>ID3v1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="67"/>
        <source>ID3v2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="74"/>
        <source>APE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="432"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="445"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="141"/>
        <source>ID3v1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>ID3v2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="192"/>
        <source>ID3v1 encoding:</source>
        <translation>Кодировка ID3v1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="224"/>
        <source>ID3v2 encoding:</source>
        <translation>Кодировка ID3v2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="272"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>MPEG Plugin Settings</source>
        <translation>Настройка модуля MPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Tag Priority</source>
        <translation>Приоритет тегов</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>First:</source>
        <translation>Первый:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>APE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="156"/>
        <source>Disabled</source>
        <translation>Выключен</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Second:</source>
        <translation>Второй:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="127"/>
        <source>Third:</source>
        <translation>Третий:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>Encodings</source>
        <translation>Кодировки</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/mad/translations/mad_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderMADFactory</name>
    <message>
        <location filename="../decodermadfactory.cpp" line="87"/>
        <source>MPEG Plugin</source>
        <translation>Модуль MPEG</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="90"/>
        <source>MPEG Files</source>
        <translation>Файлы MPEG</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="210"/>
        <source>About MPEG Audio Plugin</source>
        <translation>Об аудио-модуле MPEG</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="211"/>
        <source>Qmmp MPEG Audio Plugin</source>
        <translation>Аудио-модуль MPEG для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="212"/>
        <source>Compiled against libmad version:</source>
        <translation>Собрано с версией libmad:</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="216"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="217"/>
        <source>Source code based on mq3 progect</source>
        <translation>Исходный код основан на проекте mq3</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="115"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="138"/>
        <location filename="../detailsdialog.cpp" line="142"/>
        <source>Yes</source>
        <translation>Есть</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="140"/>
        <location filename="../detailsdialog.cpp" line="144"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="157"/>
        <location filename="../detailsdialog.ui" line="224"/>
        <source>ID3v1 Tag</source>
        <translation>ID3v1-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="462"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="378"/>
        <source>Track number:</source>
        <translation>Номер трека:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="352"/>
        <source>Year:</source>
        <translation>Год:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="404"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="326"/>
        <source>Comment:</source>
        <translation>Комментарий:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="300"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="274"/>
        <source>Artist:</source>
        <translation>Исполнитель:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="485"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="163"/>
        <source>ID3v2 Tag</source>
        <translation>ID3v2-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="91"/>
        <source>MPEG Info</source>
        <translation>Информация MPEG</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="110"/>
        <location filename="../detailsdialog.ui" line="127"/>
        <location filename="../detailsdialog.ui" line="144"/>
        <location filename="../detailsdialog.ui" line="161"/>
        <location filename="../detailsdialog.ui" line="178"/>
        <location filename="../detailsdialog.ui" line="195"/>
        <location filename="../detailsdialog.ui" line="212"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="202"/>
        <source>Original:</source>
        <translation>Оригинальный:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="185"/>
        <source>Copyright:</source>
        <translation>Авторские права:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="168"/>
        <source>Mode:</source>
        <translation>Режим:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="151"/>
        <source>File size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="134"/>
        <source>Sample rate:</source>
        <translation>Дискретизация:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="117"/>
        <source>Bit rate:</source>
        <translation>Битовая частота:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="28"/>
        <source>File path:</source>
        <translation>Путь к файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="131"/>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="20"/>
        <source>Details</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="113"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="167"/>
        <source>APE Tag</source>
        <translation>APE-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="55"/>
        <source>Tag Choice</source>
        <translation>Выбор тегов</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="61"/>
        <source>ID3v1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="68"/>
        <source>ID3v2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="75"/>
        <source>APE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="97"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="433"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="446"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <location filename="../settingsdialog.ui" line="94"/>
        <location filename="../settingsdialog.ui" line="141"/>
        <source>ID3v1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <location filename="../settingsdialog.ui" line="99"/>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>ID3v2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="183"/>
        <source>ID3v1 encoding:</source>
        <translation>Кодировка ID3v1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="206"/>
        <source>ID3v2 encoding:</source>
        <translation>Кодировка ID3v2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>MPEG Plugin Settings</source>
        <translation>Настройка модуля MPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Tag Priority</source>
        <translation>Приоритет тегов</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>First:</source>
        <translation>Первый:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <location filename="../settingsdialog.ui" line="104"/>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>APE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <location filename="../settingsdialog.ui" line="109"/>
        <location filename="../settingsdialog.ui" line="156"/>
        <source>Disabled</source>
        <translation>Выключен</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Second:</source>
        <translation>Второй:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="127"/>
        <source>Third:</source>
        <translation>Третий:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>Encodings</source>
        <translation>Кодировки</translation>
    </message>
</context>
</TS>
